@@ -1,7 +1,7 @@
 #' Add sin and cos terms for harmonic analysis
 #'
-#' `step_harmonic` creates a *specification* of a recipe step that
-#'   will add sin and cos terms for harmonic analysis.
+#' `step_harmonic()` creates a *specification* of a recipe step that will add
+#' `sin()` and `cos()` terms for harmonic analysis.
 #'
 #' @inheritParams step_pca
 #' @inheritParams step_date
@@ -58,6 +58,26 @@
 #'  24 and a `cycle_size` equal to 86400 is equivalent to a `frequency` of
 #'  1.0 with `cycle_size` equal to 3600.
 #'
+#' ```{r, echo = FALSE, results="asis"}
+#' step <- "step_harmonic"
+#' result <- knitr::knit_child("man/rmd/tunable-args.Rmd")
+#' cat(result)
+#' ```
+#'
+#' # Tidying
+#'
+#' When you [`tidy()`][tidy.recipe()] this step, a tibble is returned with
+#' columns `terms`, `starting_val`, `cycle_size`, `frequency`, `key` , and `id`:
+#'
+#' \describe{
+#'   \item{terms}{character, the selectors or variables selected}
+#'   \item{starting_val}{numeric, the starting value}
+#'   \item{cycle_size}{numeric, the cycle size}
+#'   \item{frequency}{numeric, the frequency}
+#'   \item{key}{character, key describing the calculation}
+#'   \item{id}{character, id of this step}
+#' }
+#'
 #' @template case-weights-not-supported
 #'
 #' @references Doran, H. E., & Quilkey, J. J. (1972).
@@ -151,15 +171,27 @@ step_harmonic <-
            columns = NULL,
            skip = FALSE,
            id = rand_id("harmonic")) {
-    if (!all(is.numeric(cycle_size)) | all(is.na(cycle_size))) {
-      rlang::abort("cycle_size must have at least one non-NA numeric value.")
+
+    if (!all(is.numeric(cycle_size)) || all(is.na(cycle_size))) {
+      msg <- c(
+        x = "{.arg cycle_size} must have at least one non-NA numeric value."
+      )
+
+      if (!all(is.numeric(cycle_size))) {
+        msg <- c(msg, i = "It was {.obj_type_friendly {cycle_size}}.")
+      }
+
+      cli::cli_abort(msg)
     }
 
     if (!all(is.na(starting_val)) &
       !all(is.numeric(starting_val)) &
       !all(inherits(starting_val, "Date")) &
       !all(inherits(starting_val, "POSIXt"))) {
-      rlang::abort("starting_val must be NA, numeric, Date or POSIXt")
+      cli::cli_abort(
+        "starting_val must be NA, numeric, Date or POSIXt, \\
+        not {.obj_type_friendly {starting_val}}.",
+      )
     }
 
     add_step(
@@ -211,10 +243,10 @@ prep.step_harmonic <- function(x, training, info = NULL, ...) {
   } else if (length(x$cycle_size) == length(col_names)) {
     cycle_sizes <- x$cycle_size
   } else {
-    rlang::abort(paste0(
-      "`cycle_size` must be length 1 or the same  ",
-      "length as the input columns"
-    ))
+    cli::cli_abort(
+      "{.arg cycle_size} must be length 1 or the same length as the input \\
+      columns."
+    )
   }
 
 
@@ -226,15 +258,15 @@ prep.step_harmonic <- function(x, training, info = NULL, ...) {
   } else if (length(x$starting_val) == length(col_names)) {
     starting_vals <- x$starting_val
   } else {
-    rlang::abort(paste0(
-      "`starting_val` must be length 1 or the same  ",
-      "length as the input columns"
-    ))
+    cli::cli_abort(
+      "{.arg starting_val} must be length 1 or the same length as the input \\
+      columns."
+    )
   }
 
   frequencies <- sort(unique(na.omit(x$frequency)))
 
-  names(frequencies) <- as.character(1:length(frequencies))
+  names(frequencies) <- as.character(seq_along(frequencies))
   names(starting_vals) <- col_names
   names(cycle_sizes) <- col_names
 
@@ -258,7 +290,7 @@ sin_cos <- function(x,
                     starting_val,
                     cycle_size, call = caller_env()) {
   if (all(is.na(x))) {
-    rlang::abort("variable must have at least one non-NA value", call = call)
+    cli::cli_abort("Variable must have at least one non-NA value.", call = call)
   }
 
   nc <- length(frequency)
@@ -291,29 +323,28 @@ bake.step_harmonic <- function(object, new_data, ...) {
   check_new_data(col_names, object, new_data)
 
   # calculate sin and cos columns
-  for (i in seq_along(col_names)) {
-    col_name <- col_names[i]
+  for (col_name in col_names) {
     n_frequency <- length(object$frequency)
     res <- sin_cos(
       as.numeric(new_data[[col_name]]),
       object$frequency,
-      object$starting_val[i],
-      object$cycle_size[i]
+      object$starting_val[col_name],
+      object$cycle_size[col_name]
     )
     colnames(res) <- paste0(
       col_name,
       rep(c("_sin_", "_cos_"), each = n_frequency),
-      1:n_frequency
+      seq_len(n_frequency)
     )
     res <- as_tibble(res)
-    new_data <- bind_cols(new_data, res)
+
+    res <- check_name(res, new_data, object, names(res))
+
+    new_data <- vec_cbind(new_data, res)
   }
 
-  keep_original_cols <- get_keep_original_cols(object)
-  if (!keep_original_cols) {
-    new_data <-
-      new_data[, !(colnames(new_data) %in% col_names), drop = FALSE]
-  }
+  new_data <- remove_original_cols(new_data, object, col_names)
+
   new_data
 }
 
