@@ -1,15 +1,14 @@
 #' Impute numeric data using a rolling window statistic
 #'
-#' `step_impute_roll` creates a *specification* of a
-#'  recipe step that will substitute missing values of numeric
-#'  variables by the measure of location (e.g. median) within a moving window.
+#' `step_impute_roll()` creates a *specification* of a recipe step that will
+#' substitute missing values of numeric variables by the measure of location
+#' (e.g. median) within a moving window.
 #'
 #' @inheritParams step_center
+#' @inheritParams step_pca
 #' @param ... One or more selector functions to choose variables to be imputed;
 #'  these columns must be non-integer numerics (i.e., double precision).
 #'  See [selections()] for more details.
-#' @param columns A named numeric vector of columns. This is
-#'  `NULL` until computed by [prep()].
 #' @param window The size of the window around a point to be imputed. Should be
 #'  an odd integer greater than one. See Details below for a discussion of
 #'  points at the ends of the series.
@@ -38,11 +37,22 @@
 #'  As of `recipes` 0.1.16, this function name changed from `step_rollimpute()`
 #'    to `step_impute_roll()`.
 #'
-#'  # Tidying
+#' # Tidying
 #'
-#'  When you [`tidy()`][tidy.recipe()] this step, a tibble with columns
-#'  `terms` (the selectors or variables selected) and `window`
-#'  (the window size) is returned.
+#' When you [`tidy()`][tidy.recipe()] this step, a tibble is returned with
+#' columns `terms`, `window` , and `id`:
+#'
+#' \describe{
+#'   \item{terms}{character, the selectors or variables selected}
+#'   \item{window}{integer, window size}
+#'   \item{id}{character, id of this step}
+#' }
+#'
+#' ```{r, echo = FALSE, results="asis"}
+#' step <- "step_impute_roll"
+#' result <- knitr::knit_child("man/rmd/tunable-args.Rmd")
+#' cat(result)
+#' ```
 #'
 #' @template case-weights-not-supported
 #'
@@ -78,9 +88,9 @@ step_impute_roll <-
            window = 5,
            skip = FALSE,
            id = rand_id("impute_roll")) {
-    if (!is_tune(window) & !is_varying(window)) {
+    if (!is_tune(window)) {
       if (window < 3 | window %% 2 != 1) {
-        rlang::abort("`window` should be an odd integer >= 3")
+        cli::cli_abort("{.arg window} should be an odd integer >= 3.")
       }
       window <- as.integer(floor(window))
     }
@@ -100,36 +110,6 @@ step_impute_roll <-
     )
   }
 
-#' @rdname step_impute_roll
-#' @export
-step_rollimpute <-
-  function(recipe,
-           ...,
-           role = NA,
-           trained = FALSE,
-           columns = NULL,
-           statistic = median,
-           window = 5,
-           skip = FALSE,
-           id = rand_id("impute_roll")) {
-    lifecycle::deprecate_stop(
-      when = "0.1.16",
-      what = "recipes::step_rollimpute()",
-      with = "recipes::step_impute_roll()"
-    )
-    step_impute_roll(
-      recipe,
-      ...,
-      role = role,
-      trained = trained,
-      columns = columns,
-      statistic = statistic,
-      window = window,
-      skip = skip,
-      id = id
-    )
-  }
-
 step_impute_roll_new <-
   function(terms, role, trained, columns, statistic, window, skip, id) {
     step(
@@ -162,10 +142,6 @@ prep.step_impute_roll <- function(x, training, info = NULL, ...) {
   )
 }
 
-#' @export
-#' @keywords internal
-prep.step_rollimpute <- prep.step_impute_roll
-
 get_window_ind <- function(i, n, k) {
   sides <- (k - 1) / 2
   if (i - sides >= 1 & i + sides <= n) {
@@ -201,30 +177,30 @@ impute_rolling <- function(inds, x, statfun) {
 
 #' @export
 bake.step_impute_roll <- function(object, new_data, ...) {
-  check_new_data(unname(object$columns), object, new_data)
+  col_names <- names(object$columns)
+  check_new_data(col_names, object, new_data)
 
   n <- nrow(new_data)
   missing_ind <- lapply(
-    new_data[, object$columns],
+    new_data[, col_names],
     function(x) which(is.na(x))
   )
   has_missing <- map_lgl(missing_ind, function(x) length(x) > 0)
   missing_ind <- missing_ind[has_missing]
   roll_ind <- lapply(missing_ind, get_rolling_ind, n = n, k = object$window)
 
-  for (i in seq(along.with = roll_ind)) {
-    imp_var <- names(roll_ind)[i]
-    estimates <-
-      impute_rolling(roll_ind[[i]], new_data[[imp_var]], object$statistic)
-    new_data[missing_ind[[i]], imp_var] <- estimates
+  for (col_name in col_names) {
+    estimates <- impute_rolling(
+      roll_ind[[col_name]],
+      new_data[[col_name]],
+      object$statistic
+    )
+    new_data[missing_ind[[col_name]], col_name] <- estimates
   }
+
   new_data
 }
 
-#' @export
-#' @keywords internal
-bake.step_rollimpute <- bake.step_impute_roll
-
 #' @export
 print.step_impute_roll <-
   function(x, width = max(20, options()$width - 30), ...) {
@@ -233,10 +209,6 @@ print.step_impute_roll <-
     invisible(x)
   }
 
-#' @export
-#' @keywords internal
-print.step_rollimpute <- print.step_impute_roll
-
 #' @rdname tidy.recipe
 #' @export
 tidy.step_impute_roll <- function(x, ...) {
@@ -250,24 +222,16 @@ tidy.step_impute_roll <- function(x, ...) {
   res
 }
 
-#' @export
-#' @keywords internal
-tidy.step_rollimpute <- tidy.step_impute_roll
-
 #' @export
 tunable.step_impute_roll <- function(x, ...) {
   tibble::tibble(
     name = c("statistic", "window"),
     call_info = list(
-      list(pkg = "dials", fun = "location_stat"),
-      list(pkg = "dials", fun = "window")
+      list(pkg = "dials", fun = "summary_stat"),
+      list(pkg = "dials", fun = "window_size")
     ),
     source = "recipe",
     component = "step_impute_roll",
     component_id = x$id
   )
 }
-
-#' @export
-#' @keywords internal
-tunable.step_rollimpute <- tunable.step_impute_roll
