@@ -1,8 +1,9 @@
 #' Detect a regular expression
 #'
-#' `step_regex` creates a *specification* of a recipe step that will
-#'   create a new dummy variable based on a regular expression.
+#' `step_regex()` creates a *specification* of a recipe step that will create a
+#' new dummy variable based on a regular expression.
 #'
+#' @inheritParams step_classdist
 #' @inheritParams step_pca
 #' @inheritParams step_center
 #' @param ... A single selector function to choose which variable
@@ -24,9 +25,14 @@
 #'
 #' # Tidying
 #'
-#' When you [`tidy()`][tidy.recipe()] this step, a tibble with columns
-#' `terms` (the selectors or variables selected) and `result` (the
-#' new column name) is returned.
+#' When you [`tidy()`][tidy.recipe()] this step, a tibble is returned with
+#' columns `terms`, `result` , and `id`:
+#'
+#' \describe{
+#'   \item{terms}{character, the selectors or variables selected}
+#'   \item{result}{character, new column name}
+#'   \item{id}{character, id of this step}
+#' }
 #'
 #' @template case-weights-not-supported
 #'
@@ -54,27 +60,28 @@ step_regex <- function(recipe,
                        options = list(),
                        result = make.names(pattern),
                        input = NULL,
+                       keep_original_cols = TRUE,
                        skip = FALSE,
                        id = rand_id("regex")) {
-  if (!is_tune(pattern) & !is_varying(pattern)) {
-    if (!is.character(pattern)) {
-      rlang::abort("`pattern` should be a character string")
-    }
-    if (length(pattern) != 1) {
-      rlang::abort("`pattern` should be a single pattern")
-    }
+  if (!is_tune(pattern)) {
+    check_string(pattern)
   }
   valid_args <- names(formals(grepl))[-(1:2)]
   if (any(!(names(options) %in% valid_args))) {
-    rlang::abort(paste0(
-      "Valid options are: ",
-      paste0(valid_args, collapse = ", ")
+    cli::cli_abort(c(
+      "x" = "The following elements of {.arg options} are not allowed:",
+      "*" = "{.val {setdiff(names(options), valid_args)}}.",
+      "i" = "Valid options are: {.val {valid_args}}."
     ))
   }
 
   terms <- enquos(...)
   if (length(terms) > 1) {
-    rlang::abort("For this step, at most a single selector can be used.")
+    cli::cli_abort(c(
+      x = "For this step, only a single selector can be used.",
+      i = "The following {length(terms)} selectors were used: \\
+          {.var {as.character(terms)}}."
+    ))
   }
 
   add_step(
@@ -87,6 +94,7 @@ step_regex <- function(recipe,
       options = options,
       result = result,
       input = input,
+      keep_original_cols = keep_original_cols,
       skip = skip,
       id = id
     )
@@ -94,7 +102,8 @@ step_regex <- function(recipe,
 }
 
 step_regex_new <-
-  function(terms, role, trained, pattern, options, result, input, skip, id) {
+  function(terms, role, trained, pattern, options, result, input,
+           keep_original_cols, skip, id) {
     step(
       subclass = "regex",
       terms = terms,
@@ -104,6 +113,7 @@ step_regex_new <-
       options = options,
       result = result,
       input = input,
+      keep_original_cols = keep_original_cols,
       skip = skip,
       id = id
     )
@@ -115,7 +125,11 @@ prep.step_regex <- function(x, training, info = NULL, ...) {
   check_type(training[, col_name], types = c("string", "factor", "ordered"))
 
   if (length(col_name) > 1) {
-    rlang::abort("The selector should select at most a single variable")
+    cli::cli_abort(c(
+      x = "The selector should select at most a single variable.",
+      i = "The following {length(col_name)} were selected: \\
+          {.and {.var {col_name}}}."
+    ))
   }
 
   step_regex_new(
@@ -126,24 +140,25 @@ prep.step_regex <- function(x, training, info = NULL, ...) {
     options = x$options,
     input = col_name,
     result = x$result,
+    keep_original_cols = get_keep_original_cols(x),
     skip = x$skip,
     id = x$id
   )
 }
 
+#' @export
 bake.step_regex <- function(object, new_data, ...) {
-  if (length(object$input) == 0) {
-    # Handle empty selection by adding an all `0` column
-    new_data[[object$result]] <- rep(0, times = nrow(new_data))
+  col_name <- names(object$input)
+  if (length(col_name) == 0) {
     return(new_data)
   }
 
-  check_new_data(object$input, object, new_data)
+  check_new_data(col_name, object, new_data)
 
   ## sub in options
   regex <- expr(
     grepl(
-      x = getElement(new_data, object$input),
+      x = new_data[[col_name]],
       pattern = object$pattern,
       ignore.case = FALSE,
       perl = FALSE,
@@ -155,14 +170,18 @@ bake.step_regex <- function(object, new_data, ...) {
     regex <- rlang::call_modify(regex, !!!object$options)
   }
 
-  new_data[, object$result] <- ifelse(eval(regex), 1L, 0L)
+  new_values <- tibble::tibble(!!object$result := ifelse(eval(regex), 1L, 0L))
+  new_values <- check_name(new_values, new_data, object, object$result)
+  new_data <- vec_cbind(new_data, new_values)
+  new_data <- remove_original_cols(new_data, object, col_name)
   new_data
 }
 
+#' @export
 print.step_regex <-
   function(x, width = max(20, options()$width - 30), ...) {
     title <- "Regular expression dummy variable using "
-    pattern <- glue::glue("\"{x$pattern}\"")
+    pattern <- glue("\"{x$pattern}\"")
     untrained_terms <- rlang::parse_quos(pattern, rlang::current_env())
     print_step(pattern, untrained_terms, x$trained, title, width)
     invisible(x)
