@@ -135,12 +135,9 @@ bake.step_unknown <- function(object, new_data, ...) {
       warn_new_levels(
         new_data[[col_name]],
         new_levels,
-        c(
-          "*" = "New levels will be coerced to `NA` by {.fn step_unknown}.",
-          "i" = "Consider using {.help [?step_novel](recipes::step_novel)} \\
-                before {.fn step_unknown}."
-        )
-
+        column = col_name,
+        step = "step_unknown",
+        c("*" = "New levels will be coerced to `NA` by {.fn step_unknown}.")
       )
     }
 
@@ -153,6 +150,7 @@ bake.step_unknown <- function(object, new_data, ...) {
   new_data
 }
 
+#' @export
 print.step_unknown <-
   function(x, width = max(20, options()$width - 30), ...) {
     title <- "Unknown factor level assignment for "
